@@ -8,5 +8,5 @@ def gen_password(password_len, password_count):
             for x in range(0,password_len):
                 password_char = random.choice(chars)
                 password+=password_char
-            password+="\n" 
-        return password
\ No newline at end of file
+            password="\n\n"+password
+        return password
